# Release 2.6.0 [2020-01-03]

### Improvements
  * Add a Mutalyzer Batch manager in anacore.hgvs.
  * Add management for RTAComplete.txt V2 in anacore.illumina.RTAComplete.
  * Add a conda recipe.

### Bug fixes
  * Add automatic management for multiple date formats in anacore.illumina.RunInfo.

# Release 2.5.0 [2019-10-25]
First public release

# Release 1.0.0 [2017‑10‑07]
First release
